@@ -8,8 +8,8 @@
 #define kAudioObjectPropertyElementMain (kAudioObjectPropertyElementMaster)
 #endif
 
-AudioComponent audiounit_comp_io;
-AudioComponent audiounit_comp_conv;
+extern AudioComponent audiounit_comp_io;
+extern AudioComponent audiounit_comp_conv;
 
 
 struct audiosess;
@@ -24,8 +24,8 @@ int  audiosess_alloc(struct audiosess_st **stp,
 void audiosess_interrupt(bool interrupted);
 
 
-int conv_buf_alloc(struct conv_buf **bufp, size_t framesz);
-int  get_nb_frames(struct conv_buf *buf, uint32_t *nb_frames);
+int audiounit_conv_buf_alloc(struct conv_buf **bufp, size_t framesz);
+int  audiounit_get_nb_frames(struct conv_buf *buf, uint32_t *nb_frames);
 OSStatus init_data_write(struct conv_buf *buf, void **data,
 			 size_t framesz, uint32_t nb_frames);
 OSStatus init_data_read(struct conv_buf *buf, void **data,
