@@ -4,12 +4,14 @@
  * Copyright (C) 2010 Alfred E. Heggestad
  */
 
+#if __MAC_OS_X_VERSION_MAX_ALLOWED < 120000
+#define kAudioObjectPropertyElementMain (kAudioObjectPropertyElementMaster)
+#endif
 
 int coreaudio_player_alloc(struct auplay_st **stp, const struct auplay *ap,
 			   struct auplay_prm *prm, const char *device,
 			   auplay_write_h *wh, void *arg);
 int coreaudio_recorder_alloc(struct ausrc_st **stp, const struct ausrc *as,
-			     struct media_ctx **ctx,
 			     struct ausrc_prm *prm, const char *device,
 			     ausrc_read_h *rh, ausrc_error_h *errh, void *arg);
 int coreaudio_enum_devices(const char *name, struct list *dev_list,
