@@ -12,16 +12,18 @@ struct vp9_vidcodec {
 /* Encode */
 int vp9_encode_update(struct videnc_state **vesp, const struct vidcodec *vc,
 		      struct videnc_param *prm, const char *fmtp,
-		      videnc_packet_h *pkth, void *arg);
+		      videnc_packet_h *pkth, const struct video *vid);
 int vp9_encode(struct videnc_state *ves, bool update,
 	       const struct vidframe *frame, uint64_t timestamp);
+int vp9_encode_packetize(struct videnc_state *ves,
+			 const struct vidpacket *pkt);
 
 
 /* Decode */
 int vp9_decode_update(struct viddec_state **vdsp, const struct vidcodec *vc,
-		      const char *fmtp);
+		      const char *fmtp, const struct video *vid);
 int vp9_decode(struct viddec_state *vds, struct vidframe *frame,
-	       bool *intra, bool marker, uint16_t seq, struct mbuf *mb);
+	       struct viddec_packet *pkt);
 
 
 /* SDP */
